@@ -1,5 +1,7 @@
 """
-Main interface for cognito-identity service type definitions.
+Type annotations for cognito-identity service type definitions.
+
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cognito_identity/type_defs.html)
 
 Usage::
 
@@ -13,10 +15,12 @@ import sys
 from datetime import datetime
 from typing import Dict, List
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
+from .literals import (
+    AmbiguousRoleResolutionTypeType,
+    ErrorCodeType,
+    MappingRuleMatchTypeType,
+    RoleMappingTypeType,
+)
 
 if sys.version_info >= (3, 8):
     from typing import TypedDict
@@ -27,36 +31,111 @@ else:
 __all__ = (
     "CognitoIdentityProviderTypeDef",
     "CredentialsTypeDef",
-    "IdentityDescriptionTypeDef",
-    "IdentityPoolShortDescriptionTypeDef",
-    "MappingRuleTypeDef",
-    "RoleMappingTypeDef",
-    "RulesConfigurationTypeTypeDef",
-    "UnprocessedIdentityIdTypeDef",
     "DeleteIdentitiesResponseTypeDef",
     "GetCredentialsForIdentityResponseTypeDef",
     "GetIdResponseTypeDef",
     "GetIdentityPoolRolesResponseTypeDef",
     "GetOpenIdTokenForDeveloperIdentityResponseTypeDef",
     "GetOpenIdTokenResponseTypeDef",
+    "GetPrincipalTagAttributeMapResponseTypeDef",
+    "IdentityDescriptionTypeDef",
+    "IdentityPoolShortDescriptionTypeDef",
     "IdentityPoolTypeDef",
     "ListIdentitiesResponseTypeDef",
     "ListIdentityPoolsResponseTypeDef",
     "ListTagsForResourceResponseTypeDef",
     "LookupDeveloperIdentityResponseTypeDef",
+    "MappingRuleTypeDef",
     "MergeDeveloperIdentitiesResponseTypeDef",
     "PaginatorConfigTypeDef",
+    "RoleMappingTypeDef",
+    "RulesConfigurationTypeTypeDef",
+    "SetPrincipalTagAttributeMapResponseTypeDef",
+    "UnprocessedIdentityIdTypeDef",
 )
 
 CognitoIdentityProviderTypeDef = TypedDict(
     "CognitoIdentityProviderTypeDef",
-    {"ProviderName": str, "ClientId": str, "ServerSideTokenCheck": bool},
+    {
+        "ProviderName": str,
+        "ClientId": str,
+        "ServerSideTokenCheck": bool,
+    },
     total=False,
 )
 
 CredentialsTypeDef = TypedDict(
     "CredentialsTypeDef",
-    {"AccessKeyId": str, "SecretKey": str, "SessionToken": str, "Expiration": datetime},
+    {
+        "AccessKeyId": str,
+        "SecretKey": str,
+        "SessionToken": str,
+        "Expiration": datetime,
+    },
+    total=False,
+)
+
+DeleteIdentitiesResponseTypeDef = TypedDict(
+    "DeleteIdentitiesResponseTypeDef",
+    {
+        "UnprocessedIdentityIds": List["UnprocessedIdentityIdTypeDef"],
+    },
+    total=False,
+)
+
+GetCredentialsForIdentityResponseTypeDef = TypedDict(
+    "GetCredentialsForIdentityResponseTypeDef",
+    {
+        "IdentityId": str,
+        "Credentials": "CredentialsTypeDef",
+    },
+    total=False,
+)
+
+GetIdResponseTypeDef = TypedDict(
+    "GetIdResponseTypeDef",
+    {
+        "IdentityId": str,
+    },
+    total=False,
+)
+
+GetIdentityPoolRolesResponseTypeDef = TypedDict(
+    "GetIdentityPoolRolesResponseTypeDef",
+    {
+        "IdentityPoolId": str,
+        "Roles": Dict[str, str],
+        "RoleMappings": Dict[str, "RoleMappingTypeDef"],
+    },
+    total=False,
+)
+
+GetOpenIdTokenForDeveloperIdentityResponseTypeDef = TypedDict(
+    "GetOpenIdTokenForDeveloperIdentityResponseTypeDef",
+    {
+        "IdentityId": str,
+        "Token": str,
+    },
+    total=False,
+)
+
+GetOpenIdTokenResponseTypeDef = TypedDict(
+    "GetOpenIdTokenResponseTypeDef",
+    {
+        "IdentityId": str,
+        "Token": str,
+    },
+    total=False,
+)
+
+GetPrincipalTagAttributeMapResponseTypeDef = TypedDict(
+    "GetPrincipalTagAttributeMapResponseTypeDef",
+    {
+        "IdentityPoolId": str,
+        "IdentityProviderName": str,
+        "UseDefaults": bool,
+        "PrincipalTags": Dict[str, str],
+    },
     total=False,
 )
 
@@ -73,84 +152,20 @@ IdentityDescriptionTypeDef = TypedDict(
 
 IdentityPoolShortDescriptionTypeDef = TypedDict(
     "IdentityPoolShortDescriptionTypeDef",
-    {"IdentityPoolId": str, "IdentityPoolName": str},
-    total=False,
-)
-
-MappingRuleTypeDef = TypedDict(
-    "MappingRuleTypeDef",
-    {
-        "Claim": str,
-        "MatchType": Literal["Equals", "Contains", "StartsWith", "NotEqual"],
-        "Value": str,
-        "RoleARN": str,
-    },
-)
-
-_RequiredRoleMappingTypeDef = TypedDict(
-    "_RequiredRoleMappingTypeDef", {"Type": Literal["Token", "Rules"]}
-)
-_OptionalRoleMappingTypeDef = TypedDict(
-    "_OptionalRoleMappingTypeDef",
-    {
-        "AmbiguousRoleResolution": Literal["AuthenticatedRole", "Deny"],
-        "RulesConfiguration": "RulesConfigurationTypeTypeDef",
-    },
-    total=False,
-)
-
-
-class RoleMappingTypeDef(_RequiredRoleMappingTypeDef, _OptionalRoleMappingTypeDef):
-    pass
-
-
-RulesConfigurationTypeTypeDef = TypedDict(
-    "RulesConfigurationTypeTypeDef", {"Rules": List["MappingRuleTypeDef"]}
-)
-
-UnprocessedIdentityIdTypeDef = TypedDict(
-    "UnprocessedIdentityIdTypeDef",
-    {"IdentityId": str, "ErrorCode": Literal["AccessDenied", "InternalServerError"]},
-    total=False,
-)
-
-DeleteIdentitiesResponseTypeDef = TypedDict(
-    "DeleteIdentitiesResponseTypeDef",
-    {"UnprocessedIdentityIds": List["UnprocessedIdentityIdTypeDef"]},
-    total=False,
-)
-
-GetCredentialsForIdentityResponseTypeDef = TypedDict(
-    "GetCredentialsForIdentityResponseTypeDef",
-    {"IdentityId": str, "Credentials": "CredentialsTypeDef"},
-    total=False,
-)
-
-GetIdResponseTypeDef = TypedDict("GetIdResponseTypeDef", {"IdentityId": str}, total=False)
-
-GetIdentityPoolRolesResponseTypeDef = TypedDict(
-    "GetIdentityPoolRolesResponseTypeDef",
     {
         "IdentityPoolId": str,
-        "Roles": Dict[str, str],
-        "RoleMappings": Dict[str, "RoleMappingTypeDef"],
+        "IdentityPoolName": str,
     },
     total=False,
 )
 
-GetOpenIdTokenForDeveloperIdentityResponseTypeDef = TypedDict(
-    "GetOpenIdTokenForDeveloperIdentityResponseTypeDef",
-    {"IdentityId": str, "Token": str},
-    total=False,
-)
-
-GetOpenIdTokenResponseTypeDef = TypedDict(
-    "GetOpenIdTokenResponseTypeDef", {"IdentityId": str, "Token": str}, total=False
-)
-
 _RequiredIdentityPoolTypeDef = TypedDict(
     "_RequiredIdentityPoolTypeDef",
-    {"IdentityPoolId": str, "IdentityPoolName": str, "AllowUnauthenticatedIdentities": bool},
+    {
+        "IdentityPoolId": str,
+        "IdentityPoolName": str,
+        "AllowUnauthenticatedIdentities": bool,
+    },
 )
 _OptionalIdentityPoolTypeDef = TypedDict(
     "_OptionalIdentityPoolTypeDef",
@@ -173,30 +188,112 @@ class IdentityPoolTypeDef(_RequiredIdentityPoolTypeDef, _OptionalIdentityPoolTyp
 
 ListIdentitiesResponseTypeDef = TypedDict(
     "ListIdentitiesResponseTypeDef",
-    {"IdentityPoolId": str, "Identities": List["IdentityDescriptionTypeDef"], "NextToken": str},
+    {
+        "IdentityPoolId": str,
+        "Identities": List["IdentityDescriptionTypeDef"],
+        "NextToken": str,
+    },
     total=False,
 )
 
 ListIdentityPoolsResponseTypeDef = TypedDict(
     "ListIdentityPoolsResponseTypeDef",
-    {"IdentityPools": List["IdentityPoolShortDescriptionTypeDef"], "NextToken": str},
+    {
+        "IdentityPools": List["IdentityPoolShortDescriptionTypeDef"],
+        "NextToken": str,
+    },
     total=False,
 )
 
 ListTagsForResourceResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseTypeDef", {"Tags": Dict[str, str]}, total=False
+    "ListTagsForResourceResponseTypeDef",
+    {
+        "Tags": Dict[str, str],
+    },
+    total=False,
 )
 
 LookupDeveloperIdentityResponseTypeDef = TypedDict(
     "LookupDeveloperIdentityResponseTypeDef",
-    {"IdentityId": str, "DeveloperUserIdentifierList": List[str], "NextToken": str},
+    {
+        "IdentityId": str,
+        "DeveloperUserIdentifierList": List[str],
+        "NextToken": str,
+    },
     total=False,
 )
 
+MappingRuleTypeDef = TypedDict(
+    "MappingRuleTypeDef",
+    {
+        "Claim": str,
+        "MatchType": MappingRuleMatchTypeType,
+        "Value": str,
+        "RoleARN": str,
+    },
+)
+
 MergeDeveloperIdentitiesResponseTypeDef = TypedDict(
-    "MergeDeveloperIdentitiesResponseTypeDef", {"IdentityId": str}, total=False
+    "MergeDeveloperIdentitiesResponseTypeDef",
+    {
+        "IdentityId": str,
+    },
+    total=False,
 )
 
 PaginatorConfigTypeDef = TypedDict(
-    "PaginatorConfigTypeDef", {"MaxItems": int, "PageSize": int, "StartingToken": str}, total=False
+    "PaginatorConfigTypeDef",
+    {
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
+    },
+    total=False,
+)
+
+_RequiredRoleMappingTypeDef = TypedDict(
+    "_RequiredRoleMappingTypeDef",
+    {
+        "Type": RoleMappingTypeType,
+    },
+)
+_OptionalRoleMappingTypeDef = TypedDict(
+    "_OptionalRoleMappingTypeDef",
+    {
+        "AmbiguousRoleResolution": AmbiguousRoleResolutionTypeType,
+        "RulesConfiguration": "RulesConfigurationTypeTypeDef",
+    },
+    total=False,
+)
+
+
+class RoleMappingTypeDef(_RequiredRoleMappingTypeDef, _OptionalRoleMappingTypeDef):
+    pass
+
+
+RulesConfigurationTypeTypeDef = TypedDict(
+    "RulesConfigurationTypeTypeDef",
+    {
+        "Rules": List["MappingRuleTypeDef"],
+    },
+)
+
+SetPrincipalTagAttributeMapResponseTypeDef = TypedDict(
+    "SetPrincipalTagAttributeMapResponseTypeDef",
+    {
+        "IdentityPoolId": str,
+        "IdentityProviderName": str,
+        "UseDefaults": bool,
+        "PrincipalTags": Dict[str, str],
+    },
+    total=False,
+)
+
+UnprocessedIdentityIdTypeDef = TypedDict(
+    "UnprocessedIdentityIdTypeDef",
+    {
+        "IdentityId": str,
+        "ErrorCode": ErrorCodeType,
+    },
+    total=False,
 )
